# -*-coding:utf-8 -*- #
# ---------------------------------------------------------------------------
# ProjectName:   test_56
# FileName:      read_excel.py
# Author:       xxxxxxx
# Datetime:     2023/8/4 14:36
# Description:
# 
# ---------------------------------------------------------------------------
import openpyxl
from APIAutoTest02.common.read_json import read_json
from APIAutoTest02.common.read_ini import ReadIni


class ReadExcel:
    def __init__(self):
        """获取所有json和excel文件的路径，并读取所有的json和获取excel的工作表"""
        # 创建ReadIni对象
        self.read_ini = ReadIni()
        # 获取所有的json文件的路径, 使用ReadIni对象调用get_file_path获取文件的路径
        case_data_path = self.read_ini.get_file_path("case")
        expect_data_path = self.read_ini.get_file_path("expect")
        sql_data_path = self.read_ini.get_file_path("sql")
        # 调用read_json函数读取所有的json文件
        self.case_data_dict = read_json(case_data_path)
        self.expect_data_dict = read_json(expect_data_path)
        self.sql_data_dict = read_json(sql_data_path)

        # 获取excel的路径, 使用ReadIni对象调用get_file_path获取文件的路径
        excel_path = self.read_ini.get_file_path("excel")
        # 获取工作簿
        wb = openpyxl.load_workbook(excel_path)
        table_name = self.read_ini.get_table_name("table")
        self.ws = wb[table_name]

    def __get_cell_value(self, column: str, row: int) -> str:
        """
        根据列号和行号获取指定单元格数据
        :param column:列号
        :param row:行号
        :return:单元格数据
        """
        # 根据 工作表["列号行号"].value 获取单元格数据
        value = self.ws[str(column)+str(row)].value
        # 判断单元格数据如果为None返回None
        if value is None:
            return None
        # 判断单元格数据去掉空格之后是否为空的字符串，如果是返回None，如果不是空的字符串，返回去掉前后空的字符串
        elif value.strip():
            return value.strip()

    def module_name(self, row):
        """
        根据行号获取模块名称
        :param row: 行号
        :return: 模块名称
        """
        # 调用私有方法__get_cell_value获取单元格数据
        return self.__get_cell_value("B", row)

    def interface_name(self, row):
        """
        根据行号，获取接口名称
        :param row: 行号
        :return: 接口名称
        """
        # 调用私有方法__get_cell_value获取单元格数据
        return self.__get_cell_value("c", row)

    def case_method(self, row):
        """
        根据行号，获取请求方法
        :param row: 行号
        :return: 请求方法
        """
        # 调用私有方法__get_cell_value获取单元格数据
        return self.__get_cell_value("F", row)

    def case_url(self, row):
        """
        根据行号，获取请求的url
        :param row: 行号
        :return: url
        """
        # 获取域名，使用ReadIni对象，调用get_host方法获取域名
        host = self.read_ini.get_host("test_bpm")
        path = self.__get_cell_value("g", row)
        return host+path

    def case_mime(self, row):
        """
        根据行号，获取用例的媒体类型
        :param row: 行号
        :return: 媒体类型
        """
        value = self.__get_cell_value("h", row)
        if value:
            return value.lower()

    def case_data(self, row):
        """
        根据行号，获取用例数据
        :param row: 行号
        :return: 用例数据
        """
        case_data_key = self.__get_cell_value("i", row)
        if case_data_key:
            # 获取用例json文件的路径
            # 使用read_json函数读取用例的json文件
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.case_data_dict[module_name][interface_name][case_data_key]

    def expect_data(self, row):
        """
        根据行号，获取期望数据
        :param row: 行号
        :return: 期望数据
        """
        # 获取期望数据的key，调用私有方法__get_cell_value获取单元格数据
        expect_data_key = self.__get_cell_value("j", row)
        if expect_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.expect_data_dict[module_name][interface_name][expect_data_key]

    def get_sql_type(self, row):
        """
        根据行号，获取sql语句的类型
        :param row: 行号
        :return: sql语句的类型
        """
        # 调用私有方法__get_cell_value获取单元格数据
        value = self.__get_cell_value("k", row)
        if value:
            return value.lower()

    def sql_sentence(self, row):
        """
        根据行号，获取sql语句
        :param row:
        :return:
        """
        # 获取sql语句的key，调用私有方法__get_cell_value获取单元格数据
        sql_data_key = self.__get_cell_value("l", row)
        if sql_data_key:
            module_name = self.module_name(row)
            interface_name = self.interface_name(row)
            return self.sql_data_dict[module_name][interface_name][sql_data_key]

    def update_key(self, row):
        """
        根据行号，获取更新的key
        :param row: 行号
        :return: 更新的key
        """
        # 调用私有方法__get_cell_value获取单元格数据
        value = self.__get_cell_value("m", row)
        if value:
            return value

    def get_data(self):
        """
        获取数据的数据，并存放到一个二维列表中，每行就是一个子列表
        :return: 二维列表
        """
        # 创建一个空列表，用于存放数据
        list_data = []
        # 循环取出每行的数据，并追加到空列表中
        for row in range(2, self.ws.max_row+1):
            req_method = self.case_method(row)
            url = self.case_url(row)
            mime = self.case_mime(row)
            case_data = self.case_data(row)
            expect_data = self.expect_data(row)
            sql_type = self.get_sql_type(row)
            sql_sentence = self.sql_sentence(row)
            update_key = self.update_key(row)
            list_data.append([req_method, url, mime, case_data, expect_data, sql_type, sql_sentence, update_key])
        else:
            return list_data


if __name__ == '__main__':
    read_excel = ReadExcel()
    read_excel.get_data()
